<?php
namespace PanoramaViewer\Site\BlockLayout;

use Omeka\Api\Representation\SiteRepresentation;
use Omeka\Api\Representation\SitePageRepresentation;
use Omeka\Api\Representation\SitePageBlockRepresentation;
use Omeka\Site\BlockLayout\AbstractBlockLayout;
use Laminas\View\Renderer\PhpRenderer;

use Laminas\Form\FormElementManager;

use PanoramaViewer\Form\PanoramaViewerBlockForm;

class PanoramaViewer extends AbstractBlockLayout
{
	/**
     * @var FormElementManager
     */
    protected $formElementManager;

    /**
     * @var array
     */
	protected $defaultSettings = [];

    /**
     * @param FormElementManager $formElementManager
     * @param array $defaultSettings
     */
    public function __construct(FormElementManager $formElementManager, array $defaultSettings)
    {
        $this->formElementManager = $formElementManager;
        $this->defaultSettings = $defaultSettings;
    }

	public function getLabel() {
		return 'PanoramaViewer';
	}

	public function form(PhpRenderer $view,
                       SiteRepresentation $site,
                       SitePageRepresentation $page = null,
                       SitePageBlockRepresentation $block = null
    ) {
		$form = $this->formElementManager->get(PanoramaViewerBlockForm::class);
		$data = $block
			? $block->data() + $this->defaultSettings
			: $this->defaultSettings;
		$form->setData([
			'o:block[__blockIndex__][o:data][panorama_type]' => $data['panorama_type'],
			'o:block[__blockIndex__][o:data][title]' => $data['title'],
			'o:block[__blockIndex__][o:data][height]' => $data['height'],
		]);
		$form->prepare();

		$html = '';
		$html .= $view->blockAttachmentsForm($block);
		$html .= '<a href="#" class="collapse" aria-label="collapse"><h4>' . $view->translate('Options'). '</h4></a>';
		$html .= '<div class="collapsible" style="padding-top:6px;">';
		$html .= $view->formCollection($form);
        $html .= '</div>';
		return $html;
    }

	public function render(PhpRenderer $view, SitePageBlockRepresentation $block)
	{
		$attachments = $block->attachments();
        if (!$attachments) {
            return '';
		}

		$urls = [];
		$pannellum_ids = [];
    $id = 1;
		foreach ($attachments as $attachment)
		{
			foreach($attachment->item()->media() as $media)
			{
        $id = $id +1;
        array_push($pannellum_ids, "pv-{$id}");
				$mediaType = $media->mediaType();
				$mediaRenderer = $media->renderer();
				if (strpos($mediaType, 'image/') !== false) {
					array_push($urls, $media->originalUrl());
				}
			}
		}

		return $view->partial('common/block-layout/panorama-viewer', [
			'panorama_type' => $block->dataValue('panorama_type'),
			'title' => $block->dataValue('title'),
			'height' => $block->dataValue('height'),
			'urls' => $urls,
      'pannellum_ids' => $pannellum_ids,
		]);
	}
}
